@@ -99,7 +99,7 @@ impl Enum {
         };
 
         let runtime_type = if self.0.is_winrt() {
-            let signature = Literal::byte_string(&self.0.type_signature().as_bytes());
+            let signature = Literal::byte_string(self.0.type_signature().as_bytes());
 
             quote! {
                 unsafe impl ::windows::RuntimeType for #name {
